EXPORTS
	?AddFieldToContactL@CSingleContact@@QAEXPBVCSingleContactField@@@Z @ 1 NONAME ; void CSingleContact::AddFieldToContactL(class CSingleContactField const *)
	?AddL@CContactService@@QAEXPAVCSingleContact@@ABVTDesC8@@ABVTDesC16@@2@Z @ 2 NONAME ; void CContactService::AddL(class CSingleContact *, class TDesC8 const &, class TDesC16 const &, class TDesC16 const &)
	?AddL@CContactService@@QAEXPAVMContactCallback@@HPAVCSingleContact@@ABVTDesC8@@ABVTDesC16@@3@Z @ 3 NONAME ; void CContactService::AddL(class MContactCallback *, int, class CSingleContact *, class TDesC8 const &, class TDesC16 const &, class TDesC16 const &)
	?AppendL@CSearchFields@@QAEXAAVTDesC8@@@Z @ 4 NONAME ; void CSearchFields::AppendL(class TDesC8 &)
	?Cancel@CContactService@@QAEHJ@Z @ 5 NONAME ; int CContactService::Cancel(long)
	?DeleteL@CContactService@@QAEXAAV?$RPointerArray@VTDesC8@@@@ABVTDesC16@@@Z @ 6 NONAME ; void CContactService::DeleteL(class RPointerArray<class TDesC8> &, class TDesC16 const &)
	?DeleteL@CContactService@@QAEXPAVMContactCallback@@HAAV?$RPointerArray@VTDesC8@@@@ABVTDesC16@@@Z @ 7 NONAME ; void CContactService::DeleteL(class MContactCallback *, int, class RPointerArray<class TDesC8> &, class TDesC16 const &)
	?ExportVCardL@CContactService@@QAEXABV?$TBuf@$0BAA@@@ABVTDesC8@@ABVTDesC16@@@Z @ 8 NONAME ; void CContactService::ExportVCardL(class TBuf<256> const &, class TDesC8 const &, class TDesC16 const &)
	?ExportVCardL@CContactService@@QAEXPAVMContactCallback@@HABV?$TBuf@$0BAA@@@ABVTDesC8@@ABVTDesC16@@@Z @ 9 NONAME ; void CContactService::ExportVCardL(class MContactCallback *, int, class TBuf<256> const &, class TDesC8 const &, class TDesC16 const &)
	?FieldAt@CSingleContact@@QAEPAVCSingleContactField@@H@Z @ 10 NONAME ; class CSingleContactField * CSingleContact::FieldAt(int)
	?FieldCount@CSingleContact@@QAEHXZ @ 11 NONAME ; int CSingleContact::FieldCount(void)
	?GetContactId@CSingleContact@@QAEAAVTDesC8@@XZ @ 12 NONAME ; class TDesC8 & CSingleContact::GetContactId(void)
	?GetDateTime@CSingleContactField@@QAE?AVTTime@@XZ @ 13 NONAME ; class TTime CSingleContactField::GetDateTime(void)
	?GetFieldDataL@CSingleContactField@@QAEXAAVTPtrC16@@AAV?$RPointerArray@VTDesC8@@@@@Z @ 14 NONAME ; void CSingleContactField::GetFieldDataL(class TPtrC16 &, class RPointerArray<class TDesC8> &)
	?GetFieldDataL@CSingleContactField@@QAEXAAVTPtrC8@@AAVTPtrC16@@1@Z @ 15 NONAME ; void CSingleContactField::GetFieldDataL(class TPtrC8 &, class TPtrC16 &, class TPtrC16 &)
	?GetListL@CContactService@@QAEPAVCContactIter@@W4Ttype@@ABVTDesC8@@ABVTDesC16@@PAVCSearchFields@@W4TOrder@@2@Z @ 16 NONAME ; class CContactIter * CContactService::GetListL(enum Ttype, class TDesC8 const &, class TDesC16 const &, class CSearchFields *, enum TOrder, class TDesC16 const &)
	?GetListL@CContactService@@QAEXAAVCContactIter@@@Z @ 17 NONAME ; void CContactService::GetListL(class CContactIter &)
	?GetListL@CContactService@@QAEXPAVMContactCallback@@HW4Ttype@@ABVTDesC8@@ABVTDesC16@@PAVCSearchFields@@W4TOrder@@3@Z @ 18 NONAME ; void CContactService::GetListL(class MContactCallback *, int, enum Ttype, class TDesC8 const &, class TDesC16 const &, class CSearchFields *, enum TOrder, class TDesC16 const &)
	?ImportVCardToStoreL@CContactService@@QAEXABV?$TBuf@$0BAA@@@ABVTDesC16@@@Z @ 19 NONAME ; void CContactService::ImportVCardToStoreL(class TBuf<256> const &, class TDesC16 const &)
	?ImportVCardToStoreL@CContactService@@QAEXPAVMContactCallback@@HABV?$TBuf@$0BAA@@@ABVTDesC16@@@Z @ 20 NONAME ; void CContactService::ImportVCardToStoreL(class MContactCallback *, int, class TBuf<256> const &, class TDesC16 const &)
	?NewL@CContactIter@@SAPAV1@XZ @ 21 NONAME ; class CContactIter * CContactIter::NewL(void)
	?NewL@CContactService@@SAPAV1@XZ @ 22 NONAME ; class CContactService * CContactService::NewL(void)
	?NewL@CSearchFields@@SAPAV1@PAVCContactService@@@Z @ 23 NONAME ; class CSearchFields * CSearchFields::NewL(class CContactService *)
	?NewL@CSingleContact@@SAPAV1@XZ @ 24 NONAME ; class CSingleContact * CSingleContact::NewL(void)
	?NewL@CSingleContactField@@SAPAV1@XZ @ 25 NONAME ; class CSingleContactField * CSingleContactField::NewL(void)
	?NextL@CContactIter@@QAEXAAPAVCSingleContact@@AAPAVHBufC8@@@Z @ 26 NONAME ; void CContactIter::NextL(class CSingleContact * &, class HBufC8 * &)
	?NextL@CContactIter@@QAEXAAVTPtrC16@@@Z @ 27 NONAME ; void CContactIter::NextL(class TPtrC16 &)
	?OrganiseGroupsL@CContactService@@QAEXABVTDesC8@@AAV?$RPointerArray@VTDesC8@@@@HABVTDesC16@@@Z @ 28 NONAME ; void CContactService::OrganiseGroupsL(class TDesC8 const &, class RPointerArray<class TDesC8> &, int, class TDesC16 const &)
	?OrganiseGroupsL@CContactService@@QAEXPAVMContactCallback@@HABVTDesC8@@AAV?$RPointerArray@VTDesC8@@@@HABVTDesC16@@@Z @ 29 NONAME ; void CContactService::OrganiseGroupsL(class MContactCallback *, int, class TDesC8 const &, class RPointerArray<class TDesC8> &, int, class TDesC16 const &)
	?RemoveAllFields@CSingleContact@@QAEXXZ @ 30 NONAME ; void CSingleContact::RemoveAllFields(void)
	?RemoveField@CSingleContact@@QAEHH@Z @ 31 NONAME ; int CSingleContact::RemoveField(int)
	?Reset@CContactIter@@QAEXXZ @ 32 NONAME ; void CContactIter::Reset(void)
	?SetContactIdL@CSingleContact@@QAEXABVTDesC8@@@Z @ 33 NONAME ; void CSingleContact::SetContactIdL(class TDesC8 const &)
	?SetFieldParamsL@CSingleContactField@@QAEXABVTDesC8@@ABVTDesC16@@1@Z @ 34 NONAME ; void CSingleContactField::SetFieldParamsL(class TDesC8 const &, class TDesC16 const &, class TDesC16 const &)
	?SetDateTime@CSingleContactField@@QAEXVTTime@@@Z @ 35 NONAME ; void CSingleContactField::SetDateTime(class TTime)
	?GetFieldKeyFromId@CSearchFields@@SA?AVTPtrC8@@H@Z @ 36 NONAME ; class TPtrC8 CSearchFields::GetFieldKeyFromId(int)
	?GetIdFromFieldKey@CSearchFields@@SAHAAVTDesC8@@@Z @ 37 NONAME ; int CSearchFields::GetIdFromFieldKey(class TDesC8 &)
	?GetErrKey@CContactService@@QAEHXZ @ 38 NONAME ; int CContactService::GetErrKey(void)

